@@ -4,13 +4,17 @@ Idempotent API for managing users
 from fabtools.files import is_file
 from fabtools.user import *
 
+import fabtools.require
 
-def user(name):
+
+def user(name, home=None):
     """
     Require a user
     """
     if not exists(name):
-        create(name)
+        create(name, home=home)
+    if home:
+        fabtools.require.directory(home, owner=name, use_sudo=True)
 
 
 def sudoer(username, hosts="ALL", operators="ALL", passwd=False, commands="ALL"):
